@@ -10,26 +10,20 @@ describe 'ovn::controller' do
   end
 
   shared_examples_for 'ovn controller' do
-    it 'includes params' do
-      is_expected.to contain_class('ovn::params')
-    end
-
     it 'includes controller' do
       is_expected.to contain_class('ovn::controller')
     end
 
     it 'starts controller' do
       is_expected.to contain_service('controller').with(
-        :ensure    => true,
-        :name      => platform_params[:ovn_controller_service_name],
-        :enable    => true,
-        :hasstatus => platform_params[:ovn_controller_service_status],
-        :pattern   => platform_params[:ovn_controller_service_pattern],
+        :ensure => true,
+        :name   => platform_params[:ovn_controller_service_name],
+        :enable => true,
         )
     end
 
     it 'installs controller package' do
-      is_expected.to contain_package(platform_params[:ovn_controller_package_name]).with(
+      is_expected.to contain_package('ovn-controller').with(
         :ensure => 'present',
         :name   => platform_params[:ovn_controller_package_name],
         :notify => 'Service[controller]'
@@ -39,7 +33,7 @@ describe 'ovn::controller' do
     it 'creates systemd conf' do
       is_expected.to contain_augeas('config-ovn-controller').with({
         :context => platform_params[:ovn_controller_context],
-        :changes => "set " + platform_params[:ovn_controller_option_name] + " '\"\"'",
+        :changes => "set " + platform_params[:ovn_controller_opts_envvar_name] + " '\"\"'",
       })
     end
 
@@ -249,7 +243,7 @@ describe 'ovn::controller' do
       it 'creates systemd conf' do
         is_expected.to contain_augeas('config-ovn-controller').with({
           :context => platform_params[:ovn_controller_context],
-          :changes => "set " + platform_params[:ovn_controller_option_name] + " '\"" +
+          :changes => "set " + platform_params[:ovn_controller_opts_envvar_name] + " '\"" +
                       "--ovn-controller-ssl-key=/path/to/key.pem --ovn-controller-ssl-cert=/path/to/cert.pem --ovn-controller-ssl-ca-cert=/path/to/cacert.pem" +
                       "\"'",
         })
@@ -269,24 +263,20 @@ describe 'ovn::controller' do
       when 'Debian'
         let :platform_params do
           {
-            :ovn_controller_package_name    => 'ovn-host',
-            :ovn_controller_service_name    => 'ovn-host',
-            :ovn_controller_service_status  => false,
-            :ovn_controller_service_pattern => 'ovn-controller',
-            :ovn_controller_context         => '/files/etc/default/ovn-host',
-            :ovn_controller_option_name     => 'OVN_CTL_OPTS'
+            :ovn_controller_package_name     => 'ovn-host',
+            :ovn_controller_service_name     => 'ovn-host',
+            :ovn_controller_context          => '/files/etc/default/ovn-host',
+            :ovn_controller_opts_envvar_name => 'OVN_CTL_OPTS'
           }
         end
         it_behaves_like 'ovn controller'
       when 'RedHat'
         let :platform_params do
           {
-            :ovn_controller_package_name    => 'openvswitch-ovn-host',
-            :ovn_controller_service_name    => 'ovn-controller',
-            :ovn_controller_service_status  => true,
-            :ovn_controller_service_pattern => nil,
-            :ovn_controller_context         => '/files/etc/sysconfig/ovn-controller',
-            :ovn_controller_option_name     => 'OVN_CONTROLLER_OPTS'
+            :ovn_controller_package_name     => 'openvswitch-ovn-host',
+            :ovn_controller_service_name     => 'ovn-controller',
+            :ovn_controller_context          => '/files/etc/sysconfig/ovn-controller',
+            :ovn_controller_opts_envvar_name => 'OVN_CONTROLLER_OPTS'
           }
         end
         it_behaves_like 'ovn controller'
